module TimeCrunch
  class TimeEntry
    include Enumerable
    attr_reader :employee, :timestamp

    def initialize(csv_row, employee_map)
      raise 'Row does not have four columns' unless csv_row.size == 4

      @clock_in = csv_row[0] == '3'
      @employee = employee_map.key?(csv_row[1]) ? employee_map[csv_row[1]] : csv_row[1]
      @timestamp = Time.parse("#{csv_row[2]} #{csv_row[3]}")
    end

    def clock_in?
      @clock_in
    end

    def clock_out?
      !clock_in?
    end

    def direction
      clock_in? ? 'IN' : 'OUT'
    end

    def value_by_index(ind)
      raise IndexError if ind > 2 || ind < 0
      case ind
      when 0
        direction
      when 1
        employee
      when 2
        timestamp.strftime('%Y-%m-%d %H:%M:%S')
      end
    end

    def <=>(other)
      timestamp <=> other.timestamp
    end

    def to_s
      "<direction: #{direction}, employee: #{employee}, timestamp: #{timestamp.strftime('%Y-%m-%d %H:%M:%S')}>"
    end
  end
end
